@@ -10,11 +10,6 @@ from orquestra.quantum.api.backend import QuantumBackend
 from orquestra.quantum.circuits import Circuit
 from orquestra.quantum.measurements import Measurements
 from qiskit import ClassicalRegister, QuantumCircuit, QuantumRegister, execute
-from qiskit.ignis.mitigation.measurement import (
-    CompleteMeasFitter,
-    MeasurementFilter,
-    complete_meas_cal,
-)
 from qiskit.providers.ibmq import IBMQ
 from qiskit.providers.ibmq.exceptions import (
     IBMQAccountError,
@@ -23,6 +18,8 @@ from qiskit.providers.ibmq.exceptions import (
 )
 from qiskit.providers.ibmq.job import IBMQJob
 from qiskit.result import Counts
+from qiskit.utils.mitigation import CompleteMeasFitter, complete_meas_cal
+from qiskit.utils.mitigation._filters import MeasurementFilter
 
 from orquestra.integrations.qiskit.conversions import export_to_qiskit
 
@@ -137,9 +134,10 @@ class QiskitBackend(QuantumBackend):
             n_samples_for_experiments,
             multiplicities,
         ) = self.transform_circuitset_to_ibmq_experiments(circuits, n_samples)
-        batches, n_samples_for_batches = self.batch_experiments(
-            experiments, n_samples_for_experiments
-        )
+        (
+            batches,
+            n_samples_for_batches,
+        ) = self.batch_experiments(experiments, n_samples_for_experiments)
 
         jobs = [
             self.execute_with_retries(batch, n_samples)
@@ -317,7 +315,6 @@ class QiskitBackend(QuantumBackend):
         circuit_set_from_jobs = []  # circuits that qiskit ran
         circuit_set_from_batches = []  # circuits that users sent
         self.list_virtual_to_physical_qubits_dict = []
-
         circuit_counts_set = []
         for job, batch in zip(jobs, batches):
             circuit_set_from_jobs.extend(job.circuits())
